powered by
Generate a personality test report without launching the test.
report(responses, path)
A numeric vector to represent your answers to the questions in the test.
A string to set where to store your test report.
No return value, two files named "report.Rmd" and "report.html" generates in your path.
report will be automatically called after you call launch_test and submit your responses.
report
launch_test
The report summaries your test results, and compares them to other people's to tell you what the results mean.
launch_test to launch the personality test.
# NOT RUN { if (interactive()) { # a numeric vector representing your responses to the test rs <- rep(1, 50) # generate report path <- tempdir() report(rs, path) } # }
Run the code above in your browser using DataLab